<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3474"/>
        <source>Icon size</source>
        <translation>Dimensione icone</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3483"/>
        <source>Auto merge</source>
        <translation>Organizza automaticamente</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3495"/>
        <source>Auto arrange</source>
        <translation>Disponi automaticamente</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3534"/>
        <source>Corner Settings</source>
        <translation>Impostazioni angoli di navigazione</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3543"/>
        <location filename="../view/canvasgridview.cpp" line="3548"/>
        <source>Set Wallpaper</source>
        <translation>Imposta sfondo</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3546"/>
        <source>Wallpaper and Screensaver</source>
        <translation>Sfondi e screensaver</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3732"/>
        <source>Properties</source>
        <translation>Proprietà</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3524"/>
        <source>Display Settings</source>
        <translation>Impostazioni visualizzazione</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="23"/>
        <source>Tiny</source>
        <translation>Molto piccole</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="24"/>
        <source>Small</source>
        <translation>Piccole</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="25"/>
        <source>Medium</source>
        <translation>Medie</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="26"/>
        <source>Large</source>
        <translation>Grandi</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="27"/>
        <source>Super large</source>
        <translation>Molto grandi</translation>
    </message>
</context>
<context>
    <name>DesktopMain</name>
    <message>
        <location filename="../main.cpp" line="158"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="700"/>
        <source>Wallpaper Slideshow</source>
        <translation>Slideshow sfondi</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="746"/>
        <source>When login</source>
        <translation>Al Login</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="748"/>
        <source>When wakeup</source>
        <translation>Al risveglio</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="800"/>
        <source>Require a password on wakeup</source>
        <translation>Richiedi la password per risvegliare</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="832"/>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="834"/>
        <source>Wait:</source>
        <translation>Attesa: </translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="867"/>
        <source>Wallpaper</source>
        <translation>Sfondi</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="879"/>
        <source>Screensaver</source>
        <translation>Screensaver</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="944"/>
        <source>Loading wallpapers...</source>
        <translation>Caricamento sfondi...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="946"/>
        <source>Loading screensavers...</source>
        <translation>Caricamento salvaschermo...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1004"/>
        <source>Desktop</source>
        <comment>button</comment>
        <translation>Desktop</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1005"/>
        <source>Lock Screen</source>
        <comment>button</comment>
        <translation>Lock Screen</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1006"/>
        <source>Both</source>
        <translation>Entrambe</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1094"/>
        <source>Custom Screensaver</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1095"/>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1097"/>
        <source>Apply</source>
        <comment>button</comment>
        <translation>Applica</translation>
    </message>
</context>
<context>
    <name>WaterMaskFrame</name>
    <message>
        <location filename="../view/watermaskframe.cpp" line="127"/>
        <location filename="../view/watermaskframe.cpp" line="128"/>
        <source>Not authorized</source>
        <translation>Nessuna autorizzazione</translation>
    </message>
    <message>
        <location filename="../view/watermaskframe.cpp" line="136"/>
        <location filename="../view/watermaskframe.cpp" line="137"/>
        <source>In trial period</source>
        <translation>Periodo di prova</translation>
    </message>
</context>
</TS>